.. _sec-GNU-Linux:

Linux Package Managers
======================

SageMath is available from various distributions and can be installed
by package managers.

As of Sage 10.2, we can recommend the following distributions, which
provide well-maintained and up-to-date SageMath packages:
`Arch Linux <https://archlinux.org/>`_
and `Void Linux <https://voidlinux.org/>`_.

Gentoo users might want to give a try to
`sage-on-gentoo <https://github.com/cschwan/sage-on-gentoo>`_.

**Do not install a version of Sage older than 9.5.**
If you are on an older version of your distribution and a recent
version of SageMath is only available on a newer version of the
distribution, consider upgrading your distribution.

See `the _sagemath dummy package <../reference/spkg/_sagemath.html>`_
for the names of packages that provide a standard installation of
SageMath, including documentation and Jupyter.  See also `repology.org: sagemath
<https://repology.org/project/sagemath/versions>`_ for information
about versions of SageMath packages in various distributions.

The  `GitHub wiki page Distribution <https://github.com/sagemath/sage/wiki/Distribution>`_ collects information
regarding packaging and distribution of SageMath.
